==> ejc-ztpcct-impl-3.0.0-20240428.030022-123-sources.jar: com/ejianc/ztpc/bean/ProjectImplementPlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目实施计划表
 * 
 * @author generator
 * 
 */
 @TableName("ct_project_implement_plan")
public class ProjectImplementPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="bill_code")
    private String billCode; // 文件编码
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="file_name")
    private String fileName; // 文件名称
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="supervisor")
    private String supervisor; // 监理单位
    @TableField(value="contract_tax_mny")
    private BigDecimal contractTaxMny; // 合同(签订)金额
    @TableField(value="schedule")
    private Integer schedule; // 工期
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="memo")
    private String memo; // 工程范围
    @TableField(value="text_attachment")
    private String textAttachment; // 正文附件
    @TableField(value="text_attachment_id")
    private Long textAttachmentId; // 正文附件id
    @TableField(value="chief_engineer_id")
    private Long chiefEngineerId; // 项目总工
    @TableField(value="chief_engineer")
    private String chiefEngineer; // 项目总工名称
    @TableField(value="designer")
    private String designer; // 设计单位
    @TableField(value="project_management_id")
    private Long projectManagementId; // 项目经理id
    @TableField(value="project_management_name")
    private String projectManagementName; // 项目经理
    @TableField(value="construct_id")
    private Long constructId; // 建设单位id
    @TableField(value="construct_name")
    private String constructName; // 建设单位
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="area_name")
    private String areaName; // 地区
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同(签订)金额(不含税)
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="submit_type")
    private Long submitType; // 文件报审类型

    @TableField(exist = false)
    @SubEntity(serviceName = "opinionInfoService")
    private List<OpinionInfoEntity> opinionInfoList; // 意见栏

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public String getSupervisor() {
        return supervisor;
    }

    public void setSupervisor(String supervisor) {
        this.supervisor = supervisor;
    }
    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    public Integer getSchedule() {
        return schedule;
    }

    public void setSchedule(Integer schedule) {
        this.schedule = schedule;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }
    public Long getTextAttachmentId() {
        return textAttachmentId;
    }

    public void setTextAttachmentId(Long textAttachmentId) {
        this.textAttachmentId = textAttachmentId;
    }
    public Long getChiefEngineerId() {
        return chiefEngineerId;
    }

    public void setChiefEngineerId(Long chiefEngineerId) {
        this.chiefEngineerId = chiefEngineerId;
    }
    public String getChiefEngineer() {
        return chiefEngineer;
    }

    public void setChiefEngineer(String chiefEngineer) {
        this.chiefEngineer = chiefEngineer;
    }
    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }
    public Long getProjectManagementId() {
        return projectManagementId;
    }

    public void setProjectManagementId(Long projectManagementId) {
        this.projectManagementId = projectManagementId;
    }
    public String getProjectManagementName() {
        return projectManagementName;
    }

    public void setProjectManagementName(String projectManagementName) {
        this.projectManagementName = projectManagementName;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public List<OpinionInfoEntity> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<OpinionInfoEntity> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    public Long getSubmitType() {
        return submitType;
    }

    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }
}

==> ejc-ztpcct-impl-3.0.0-20250320.081541-198-sources.jar: com/ejianc/ztpc/bean/ProjectImplementPlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目实施计划表
 * 
 * @author generator
 * 
 */
 @TableName("ct_project_implement_plan")
public class ProjectImplementPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="bill_code")
    private String billCode; // 文件编码
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="file_name")
    private String fileName; // 文件名称
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="supervisor")
    private String supervisor; // 监理单位
    @TableField(value="contract_tax_mny")
    private BigDecimal contractTaxMny; // 合同(签订)金额
    @TableField(value="schedule")
    private Integer schedule; // 工期
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="memo")
    private String memo; // 工程范围
    @TableField(value="text_attachment")
    private String textAttachment; // 正文附件
    @TableField(value="text_attachment_id")
    private Long textAttachmentId; // 正文附件id
    @TableField(value="chief_engineer_id")
    private Long chiefEngineerId; // 项目总工
    @TableField(value="chief_engineer")
    private String chiefEngineer; // 项目总工名称
    @TableField(value="designer")
    private String designer; // 设计单位
    @TableField(value="project_management_id")
    private Long projectManagementId; // 项目经理id
    @TableField(value="project_management_name")
    private String projectManagementName; // 项目经理
    @TableField(value="construct_id")
    private Long constructId; // 建设单位id
    @TableField(value="construct_name")
    private String constructName; // 建设单位
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="area_name")
    private String areaName; // 地区
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同(签订)金额(不含税)
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="submit_type")
    private Long submitType; // 文件报审类型
    @TableField(value = "penetrating_project")
    private Integer penetratingProject;// 是否穿透式项目(0否1是)
    @TableField(value = "sub_org_id")
    private Long subOrgId;// 分子公司

    @TableField(exist = false)
    @SubEntity(serviceName = "opinionInfoService")
    private List<OpinionInfoEntity> opinionInfoList; // 意见栏

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public String getSupervisor() {
        return supervisor;
    }

    public void setSupervisor(String supervisor) {
        this.supervisor = supervisor;
    }
    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    public Integer getSchedule() {
        return schedule;
    }

    public void setSchedule(Integer schedule) {
        this.schedule = schedule;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }
    public Long getTextAttachmentId() {
        return textAttachmentId;
    }

    public void setTextAttachmentId(Long textAttachmentId) {
        this.textAttachmentId = textAttachmentId;
    }
    public Long getChiefEngineerId() {
        return chiefEngineerId;
    }

    public void setChiefEngineerId(Long chiefEngineerId) {
        this.chiefEngineerId = chiefEngineerId;
    }
    public String getChiefEngineer() {
        return chiefEngineer;
    }

    public void setChiefEngineer(String chiefEngineer) {
        this.chiefEngineer = chiefEngineer;
    }
    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }
    public Long getProjectManagementId() {
        return projectManagementId;
    }

    public void setProjectManagementId(Long projectManagementId) {
        this.projectManagementId = projectManagementId;
    }
    public String getProjectManagementName() {
        return projectManagementName;
    }

    public void setProjectManagementName(String projectManagementName) {
        this.projectManagementName = projectManagementName;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public List<OpinionInfoEntity> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<OpinionInfoEntity> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    public Long getSubmitType() {
        return submitType;
    }

    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }

    public Integer getPenetratingProject() {
        return penetratingProject;
    }

    public void setPenetratingProject(Integer penetratingProject) {
        this.penetratingProject = penetratingProject;
    }

    public Long getSubOrgId() {
        return subOrgId;
    }

    public void setSubOrgId(Long subOrgId) {
        this.subOrgId = subOrgId;
    }
}
